/* Copyright 2016 The Chromium OS Authors. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */

#ifndef __CHIP_STM32_USB_DWC_CONSOLE_H
#define __CHIP_STM32_USB_DWC_CONSOLE_H

#include "usb_hw.h"

extern struct dwc_usb_ep ep_console_ctl;

#endif  /* __CHIP_STM32_USB_DWC_CONSOLE_H */
